@@ -1,16 +1,17 @@
 import React from 'react';
 import PropTypes from 'prop-types';
 import { Utils } from '../../../utils/utils';
+import Icon from '../../icon';
 
 const propTypes = {
   text: PropTypes.string.isRequired,
-  iconClass: PropTypes.string.isRequired,
+  iconSymbol: PropTypes.string.isRequired,
   op: PropTypes.func.isRequired
 };
 
 class Item extends React.Component {
   render() {
-    const { text, op, iconClass } = this.props;
+    const { text, op, iconSymbol } = this.props;
     return (
       <div
         role="button"
@@ -20,7 +21,7 @@ class Item extends React.Component {
         onClick={op}
         onKeyDown={Utils.onKeyDown}
       >
-        <span className={iconClass}></span>
+        <span className="d-flex align-items-center"><Icon symbol={iconSymbol} /></span>
         <span className="dir-others-item-text">{text}</span>
       </div>
     );
