@@ -793,11 +793,10 @@ class DirentListItem extends React.Component {
             onMouseDown={this.onItemMouseDown}
             onContextMenu={this.onItemContextMenu}
           >
-            <td className={classnames('pl10 pr-2 cursor-pointer', { 'tr-drag-effect': this.state.isDragTipShow })}>
+            <td className={classnames('pl10 pr-2 cursor-pointer', { 'tr-drag-effect': this.state.isDragTipShow })} onClick={this.onItemSelected}>
               <input
                 type="checkbox"
-                className="vam cursor-pointer"
-                style={{ position: 'relative', top: -1 }}
+                className="cursor-pointer form-check-input"
                 checked={isSelected}
                 aria-label={isSelected ? gettext('Unselect this item') : gettext('Select this item')}
                 title={isSelected ? gettext('Unselect this item') : gettext('Select this item')}
