@@ -8,6 +8,8 @@ import { Utils } from '../../utils/utils';
 import Dirent from '../../models/dirent';
 import toaster from '../toast';
 import Icon from '../icon';
+import { gettext } from '../../utils/constants';
+import OpIcon from '../op-icon';
 
 const propTypes = {
   isCurrentRepo: PropTypes.bool,
@@ -77,7 +79,10 @@ class RepoListItem extends React.Component {
       parentPath = pathElements.join('/');
     }
     // create new folder in selected repo or folder
-    if (repo && selectedRepo && repo.repo_id === selectedRepo.repo_id && prevProps.selectedRepo !== selectedRepo && this.isComponentMounted) {
+    if (!this.isComponentMounted || !repo || !selectedRepo) return;
+    const isSameRepo = repo.repo_id === selectedRepo.repo_id;
+    const isNewlySelectedRepo = !prevProps.selectedRepo || prevProps.selectedRepo.repo_id !== selectedRepo.repo_id;
+    if (isSameRepo && isNewlySelectedRepo) {
       seafileAPI.listDir(repo.repo_id, parentPath).then(res => {
         const { dirent_list = [], dir_id = '', user_perm = 'r' } = res?.data || {};
         const dirent = dirent_list.find(item => item.type === 'dir' && item.name === newFolderName);
@@ -222,7 +227,7 @@ class RepoListItem extends React.Component {
 
   onRepoItemClick = (e) => {
     const { repo, selectedPath } = this.props;
-    if (!this.isCurrentRepo() || (selectedPath !== '' && selectedPath !== '/')) {
+    if (!this.isCurrentRepo() || (selectedPath !== '/')) {
       this.props.onRepoItemClick(repo);
     } else {
       this.onToggleClick(e);
@@ -244,9 +249,20 @@ class RepoListItem extends React.Component {
 
     return (
       <li>
-        <div className={`${repoActive ? 'item-active' : ''} item-info`} onClick={this.onRepoItemClick}>
+        <div
+          className={`${repoActive ? 'item-active' : ''} item-info`}
+          onClick={this.onRepoItemClick}
+          tabIndex={0}
+          role="treeitem"
+          aria-selected={repoActive}
+          onKeyDown={Utils.onKeyDown}
+        >
           <div className="item-left-icon">
-            <span className={`item-toggle icon sf3-font sf3-font-down ${this.state.isShowChildren ? '' : 'rotate-270 d-inline-block'}`} onClick={this.onToggleClick}></span>
+            <OpIcon
+              className={`item-toggle icon sf3-font sf3-font-down ${this.state.isShowChildren ? '' : 'rotate-270 d-inline-block'}`}
+              op={this.onToggleClick}
+              title={this.state.isShowChildren ? gettext('Fold') : gettext('Unfold')}
+            />
             <i className="tree-node-icon">
               <span className="icon sf3-font sf3-font-folder tree-node-icon"></span>
             </i>
