@@ -7,6 +7,8 @@ import TextTranslation from '../../utils/text-translation';
 import ItemDropdownMenu from '../dropdown-menu/item-dropdown-menu';
 import { getFileNameFromRecord } from '../../metadata/utils/cell/core';
 import { Utils } from '../../utils/utils';
+import OpIcon from '../../components/op-icon';
+import OpElement from '../../components/op-element';
 import { openInNewTab, openParentFolder } from '../../metadata/utils/file';
 import { checkIsDir } from '../../metadata/utils/row';
 import { useMetadataStatus } from '../../hooks';
@@ -14,7 +16,6 @@ import { getColumnByKey } from '../../metadata/utils/column';
 
 const GalleryFilesToolbar = () => {
   const [selectedRecordIds, setSelectedRecordIds] = useState([]);
-  const [isSomeone, setIsSomeone] = useState(false);
   const metadataRef = useRef([]);
   const menuRef = useRef(null);
 
@@ -32,10 +33,9 @@ const GalleryFilesToolbar = () => {
   }, []);
 
   useEffect(() => {
-    const unsubscribeSelectedFileIds = eventBus && eventBus.subscribe(EVENT_BUS_TYPE.SELECT_RECORDS, (ids, metadata, isSomeone) => {
+    const unsubscribeSelectedFileIds = eventBus && eventBus.subscribe(EVENT_BUS_TYPE.SELECT_RECORDS, (ids, metadata) => {
       metadataRef.current = metadata || [];
       setSelectedRecordIds(ids);
-      setIsSomeone(isSomeone);
     });
 
     const unsubscribeMetadata = eventBus && eventBus.subscribe(EVENT_BUS_TYPE.UPDATE_METADATA, (updatedMetadata) => {
@@ -62,10 +62,10 @@ const GalleryFilesToolbar = () => {
       records,
       readOnly,
       metadataStatus,
-      isSomeone,
+      null,
       faceRecognitionPermission
     );
-  }, [records, readOnly, enableFaceRecognition, enableTags, isSomeone, faceRecognitionPermission]);
+  }, [records, readOnly, enableFaceRecognition, enableTags, faceRecognitionPermission]);
 
   const onMenuItemClick = useCallback((operation) => {
     switch (operation) {
@@ -148,28 +148,39 @@ const GalleryFilesToolbar = () => {
   const length = selectedRecordIds.length;
   return (
     <div className="selected-dirents-toolbar">
-      <span className="cur-view-path-btn px-2" onClick={unSelect}>
-        <span className="sf3-font-x-01 sf3-font mr-2" aria-label={gettext('Unselect')} title={gettext('Unselect')}></span>
+      <OpElement
+        className="cur-view-path-btn px-2"
+        title={gettext('Unselect')}
+        op={unSelect}
+      >
+        <span className="sf3-font-x-01 sf3-font mr-2"></span>
         <span>{length}{' '}{gettext('selected')}</span>
-      </span>
-
+      </OpElement>
       {length === 1 && !readOnly && (
         <>
-          <span className="cur-view-path-btn" onClick={onMoveClick} title={gettext('Move')}>
-            <span className="sf3-font-move sf3-font" aria-label={gettext('Move')}></span>
-          </span>
-          <span className="cur-view-path-btn" onClick={onCopyClick} title={gettext('Copy')}>
-            <span className="sf3-font-copy1 sf3-font" aria-label={gettext('Copy')}></span>
-          </span>
+          <OpIcon
+            className="cur-view-path-btn sf3-font-move1 sf3-font"
+            title={gettext('Move')}
+            op={onMoveClick}
+          />
+          <OpIcon
+            className="cur-view-path-btn sf3-font-copy1 sf3-font"
+            title={gettext('Copy')}
+            op={onCopyClick}
+          />
         </>
       )}
-      <span className="cur-view-path-btn" onClick={onDownloadClick} title={gettext('Download')}>
-        <span className="sf3-font-download1 sf3-font" aria-label={gettext('Download')}></span>
-      </span>
+      <OpIcon
+        className="cur-view-path-btn sf3-font-download1 sf3-font"
+        title={gettext('Download')}
+        op={onDownloadClick}
+      />
       {!readOnly && (
-        <span className="cur-view-path-btn" onClick={onDeleteClick} title={gettext('Delete')}>
-          <span className="sf3-font-delete1 sf3-font" aria-label={gettext('Delete')}></span>
-        </span>
+        <OpIcon
+          className="cur-view-path-btn sf3-font-delete1 sf3-font"
+          title={gettext('Delete')}
+          op={onDeleteClick}
+        />
       )}
 
       {toolbarMenuOptions.length > 0 && (
