@@ -1,14 +1,18 @@
 import React from 'react';
 import PropTypes from 'prop-types';
 import { gettext } from '../../utils/constants';
+import { Utils } from '../../utils/utils';
 
 function WikiCardItemAdd(props) {
   return (
     <div
       className={'wiki-card-item wiki-card-item-add d-flex flex-column align-items-center justify-content-center'}
       onClick={props.toggleAddWikiDialog}
+      onKeyDown={Utils.onKeyDown}
+      role="button"
+      tabIndex="0"
     >
-      <span>+</span>
+      <span aria-hidden={true}>+</span>
       <span>{gettext('Add Wiki')}</span>
     </div>
   );
